:mod:`art.experimental.estimators.classification`
=================================================
.. automodule:: art.experimental.estimators.classification

JAX Classifier
--------------
.. autoclass:: JaxClassifier
   :members:
   :special-members: __init__
   :inherited-members:
